import * as cdk from '@aws-cdk/core';
/**
 * The supported annotation types.
 *
 * Only error will stop deployment of restricted resources.
 *
 * @stability stable
 */
export declare enum AnnotationType {
    /**
     * @stability stable
     */
    WARNING = "warning",
    /**
     * @stability stable
     */
    ERROR = "error",
    /**
     * @stability stable
     */
    INFO = "info"
}
/**
 * The base aspect properties available to any aspect.
 *
 * JSII doesn't support an Omit when extending interfaces, so we create a base class to extend from.
 * This base class meets the needed properties for all non-base aspects.
 *
 * @stability stable
 */
export interface IAspectPropsBase {
    /**
     * The annotation text to use for the annotation.
     *
     * @stability stable
     */
    annotationText?: string;
    /**
     * The annotation type to use for the annotation.
     *
     * @stability stable
     */
    annotationType?: AnnotationType;
}
/**
 * The extended aspect properties available only to the SecurityGroupAspectBase.
 *
 * These additional properties shouldn't be changed in aspects that already have clearly defined goals.
 * So, this extended properties interface is applied selectively to the SecurityGroupAspectBase.
 *
 * @stability stable
 */
export interface IAspectPropsExtended extends IAspectPropsBase {
    /**
     * The restricted port.
     *
     * Defaults to restricting all ports and only checking sources.
     *
     * @default undefined
     * @stability stable
     */
    ports?: number[];
    /**
     * The restricted CIDRs for the given port.
     *
     * @default ['0.0.0.0/0', '::/0']
     * @stability stable
     */
    restrictedCidrs?: string[];
    /**
     * The restricted source security groups for the given port.
     *
     * @default undefined
     * @stability stable
     */
    restrictedSGs?: string[];
    /**
     * Whether any source is valid.
     *
     * This will ignore all other restrictions and only check the port.
     *
     * @default false
     * @stability stable
     */
    anySource?: boolean;
}
/**
 * @function anyInRange
 * Function to check if a number is in a range.
 *
 * Useful for determining if a port number in a security group is in part of a range since rules take a to and from port.
 *
 * @param num The number to check.
 * @param from The starting number of the range.
 * @param to The ending number of the range.
 */
export declare function anyInRange(num: number[], from: number, to: number): boolean;
/**
 * @function annotate
 * Function to annotate a construct node based on a defined annotation type.
 *
 * @param {cdk.IConstruct} node The construct node to annotate.
 * @param {string} annotationText The annotation text to use for the annotation.
 * @param {AnnotationType} annotationType The annotation type to use for the annotation.
 */
export declare function annotate(node: cdk.IConstruct, annotationText: string | undefined, annotationType: AnnotationType | undefined): void;
/**
 * The arguments for the checkRules function.
 *
 * Extends the IAspectPropsBase interface which includes additional properties that can be used as args.
 *
 * @stability stable
 */
export interface IRuleCheckArgs extends IAspectPropsExtended {
    /**
     * The node to check.
     *
     * @stability stable
     */
    node: cdk.IConstruct;
}
/**
 * @function checkRules
 *
 * @param {IRuleCheckArgs} args The arguments for the checkRules function.
 *
 * Function to check a node for security group rules and determine if they breaks the rules of a given aspect.
 */
export declare function checkRules(args: IRuleCheckArgs): void;
/**
 * The base class for all security group aspects in the library.
 *
 * By default this will restrict all ports that use the typical "any" CIDRs on AWS (0.0.0.0/0 and ::/0) and
 * will generate an error in the CDK metadata with a generic error about a blocked security group rule.
 *
 * @stability stable
 */
export declare class SecurityGroupAspectBase implements cdk.IAspect {
    /**
     * @stability stable
     */
    annotationText: string;
    /**
     * @stability stable
     */
    annotationType: AnnotationType;
    /**
     * @stability stable
     */
    ports: number[] | undefined;
    /**
     * @stability stable
     */
    restrictedCidrs: string[] | undefined;
    /**
     * @stability stable
     */
    restrictedSGs: string[] | undefined;
    /**
     * @stability stable
     */
    anySource: boolean;
    /**
     * @stability stable
     */
    constructor(props?: IAspectPropsExtended);
    /**
     * All aspects can visit an IConstruct.
     *
     * @stability stable
     */
    visit(node: cdk.IConstruct): void;
}
/**
 * Aspect to determine if a security group allows inbound traffic from the public internet to any port.
 *
 * This inherits everything from the base SecurityGroupAspectBase class and modifies the default annotation text.
 *
 * @stability stable
 */
export declare class NoPublicIngressAspect extends SecurityGroupAspectBase implements cdk.IAspect {
    /**
     * @stability stable
     */
    constructor(props?: IAspectPropsBase);
}
/**
 * Aspect to determine if a security group allows inbound traffic from the public internet to the SSH port.
 *
 * @stability stable
 */
export declare class NoPublicIngressSSHAspect extends SecurityGroupAspectBase {
    /**
     * @stability stable
     */
    constructor(props?: IAspectPropsBase);
}
/**
 * CIS AWS Foundations Benchmark 4.1.
 *
 * CIS recommends that no security group allow unrestricted ingress access to port 22. Removing unfettered connectivity to remote console services, such as SSH, reduces a server's exposure to risk.
 *
 * This aspect uses the NoPublicIngressSSHAspect with an alternate annotation text.
 *
 * @stability stable
 */
export declare class CISAwsFoundationBenchmark4Dot1Aspect extends NoPublicIngressSSHAspect {
    /**
     * @stability stable
     */
    constructor(props?: IAspectPropsBase);
}
/**
 * Aspect to determine if a security group allows inbound traffic from the public internet to the RDP port.
 *
 * @stability stable
 */
export declare class NoPublicIngressRDPAspect extends SecurityGroupAspectBase {
    /**
     * @stability stable
     */
    constructor(props?: IAspectPropsBase);
}
/**
 * CIS AWS Foundations Benchmark 4.2.
 *
 * CIS recommends that no security group allow unrestricted ingress access to port 3389. Removing unfettered connectivity to remote console services, such as RDP, reduces a server's exposure to risk.
 *
 * This aspect uses the NoPublicIngressRDPAspect with an alternate annotation text.
 *
 * @stability stable
 */
export declare class CISAwsFoundationBenchmark4Dot2Aspect extends NoPublicIngressRDPAspect {
    /**
     * @stability stable
     */
    constructor(props?: IAspectPropsBase);
}
/**
 * Restricted common ports based on AWS Config rule https://docs.aws.amazon.com/config/latest/developerguide/restricted-common-ports.html.
 *
 * @stability stable
 */
export declare class AWSRestrictedCommonPortsAspect extends SecurityGroupAspectBase {
    /**
     * @stability stable
     */
    constructor(props?: IAspectPropsBase);
}
